#
# Test AcquisitionUnderstander
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase

from AccessControl import Unauthorized

from Products.AcquisitionUnderstander import UseUnderstanderPermission
standard_permissions = ZopeTestCase.standard_permissions
access_permissions = [UseUnderstanderPermission]

ZopeTestCase.installProduct('AcquisitionUnderstander')


class TestAcquisitionUnderstander(ZopeTestCase.ZopeTestCase):

    def test_00_ItemPatched(self):
        '''Item should have been patched'''
        ob = getattr(self.app, 'aq_base', self.app)
        self.failUnless(hasattr(ob, 'showaq'))

    def test_01_AccessAllowed(self):
        'showaq should be accessible'
        self.setPermissions(standard_permissions+access_permissions)
        try:
            dummy = self.folder.restrictedTraverse('showaq')
        except Unauthorized:
            self.fail('Access to showaq was denied')
            
    def test_02_AccessDenied(self):
        'showaq should be protected'
        self.setPermissions(standard_permissions)
        try:
            dummy = self.folder.restrictedTraverse('showaq')
        except Unauthorized:
            pass
        else:
            self.fail('Access to showaq was allowed')
            
    def test_03_ManagerAccessAllowed(self):
        'showaq should be accessible to Managers'
        self.setRoles(['Manager'])
        try:
            dummy = self.folder.restrictedTraverse('showaq')
        except Unauthorized:
            self.fail('Access to showaq was denied to Manager')
            
    def test_04_ManagerAccessDenied(self):
        'showaq should be protected from Managers'
        self.folder.manage_permission(UseUnderstanderPermission, [], acquire=0)
        self.setRoles(['Manager'])
        try:
            dummy = self.folder.restrictedTraverse('showaq')
        except Unauthorized:
            pass
        else:
            self.fail('Access to showaq was allowed to Manager')

            
def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestAcquisitionUnderstander))
    return suite

if __name__ == '__main__':
    framework()
